@@ -4,7 +4,7 @@ use warnings;
 use base qw{Pod::Parser};
 
 # Set our version
-our $VERSION = '0.00002';
+our $VERSION = '0.00003';
 
 # Hold data for our pending statement
 my $info = {};
@@ -218,6 +218,8 @@ sub sql {
 
 sub template {
     my ($self, %arg) = @_;
+    return $self->sql
+        unless scalar %arg;
     $self->{_template} ||= Text::Template->new(
         TYPE => 'STRING',
         SOURCE => $self->sql,
@@ -240,6 +242,10 @@ sub template {
 
 ¡ ¡ ¡ ALL GLORY TO GLORIA ! ! !
 
+=head1 VERSION
+
+0.00003
+
 =head1 NAME
 
 DBIx::POS::Template - is a fork of L<DBIx::POS>. Define a dictionary of SQL statements in a POD dialect (POS) plus expand template sql with embedded Perl by L<Text::Template>.
@@ -313,7 +319,7 @@ Some options will passing to Text::Template->new() for each parsed statement. By
 
 =back
 
-=head2 instance(file, <options>)
+=head2 instance($file, <options>)
 
 Return singleton dictionary object, parsed $file keys will collapse/override with previous files. Same options as C<new>, I<tt> option merge with previous options of instance invokes.
 
